<?php

namespace App\Controller;

use App\Entity\Etablissement;
use App\Form\EtablissementType;
use App\Repository\EtablissementRepository;
use Knp\Component\Pager\PaginatorInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

#[Route('/etablissement')]
class EtablissementController extends AbstractController
{
    #[Route('/', name: 'app_etablissement_index', methods: ['GET'])]
    public function index(EtablissementRepository $etablissementRepository, Request $request, PaginatorInterface $paginator): Response
    {
        $etab = $etablissementRepository->findAll();

        $articles = $paginator->paginate(
            $etab,
            $request->query->getInt('page', 1),
            20
        );
//        return $this->render('etablissement/index.html.twig', [
//            'etablissements' => $etablissementRepository->findAll(),
//        ]);
        return $this->render('etablissement/index.html.twig', array(
            'articles' => $articles,'etablissements' => $etab ));
    }

    /* Filtre Département */

    /**
     * @Route("/departement/{departement}", name="etablissement_departement")
     */
    public function showDepartement(string $departement, Request $request, PaginatorInterface $paginator) {

        $etablissements = $this->getDoctrine()
            ->getRepository(Etablissement::class)
            ->findByDepartement($departement);

        if (!$etablissements) {
            throw $this->createNotFoundException(
                "Aucun établissement avec ce département ".$departement
            );
        }

        $articles = $paginator->paginate(
            $etablissements,
            $request->query->getInt('page', 1),
            20
        );

        return $this->render('etablissement/etablissement.html.twig', array(
            'articles' => $articles,'vu'=>' Département : '.$departement));

    }

    /* Filtre Commune */

    /**
     * @Route("/commune/{commune}", name="etablissement_commune")
     */
    public function showCommune(string $commune, Request $request, PaginatorInterface $paginator) {

        $etablissements = $this->getDoctrine()
            ->getRepository(Etablissement::class)
            ->findByCommune($commune);

        if (!$etablissements) {
            throw $this->createNotFoundException(
                "Aucun établissement avec cette commune ".$commune
            );
        }

        $articles = $paginator->paginate(
            $etablissements,
            $request->query->getInt('page', 1),
            50
        );

        return $this->render('etablissement/etablissement.html.twig', array(
            'articles' => $articles,'vu'=>' Commune : '.$commune));

    }

    /* Filtre Région */

    /**
     * @Route("/region/{region}", name="etablissement_region")
     */
    public function showRegion(string $region, Request $request, PaginatorInterface $paginator) {

        $etablissements = $this->getDoctrine()
            ->getRepository(Etablissement::class)
            ->findByRegion($region);

        if (!$etablissements) {
            throw $this->createNotFoundException(
                "Aucun établissement avec cette région ".$region
            );
        }

        $articles = $paginator->paginate(
            $etablissements,
            $request->query->getInt('page', 1),
            50
        );

        return $this->render('etablissement/etablissement.html.twig', array(
            'articles' => $articles,'vu'=>' Région : '.$region));
    }

    /* Filtre Académie */

    /**
     * @Route("/academie/{academie}", name="etablissement_academie")
     */
    public function showAcademie(string $academie, Request $request, PaginatorInterface $paginator) {

        $etablissements = $this->getDoctrine()
            ->getRepository(Etablissement::class)
            ->findByAcademie($academie);

        if (!$etablissements) {
            throw $this->createNotFoundException(
                "Aucun établissement avec cette académie ".$academie
            );
        }

        $articles = $paginator->paginate(
            $etablissements,
            $request->query->getInt('page', 1),
            50
        );

        return $this->render('etablissement/etablissement.html.twig', array(
            'articles' => $articles,'vu'=>' Académie : '.$academie));
    }

    /* Filtre Secteur */

    /**
     * @Route("/secteur/{secteur}", name="etablissement_secteur")
     */
//    #[Route('/secteur/{secteur}', name: 'etablissement_secteur')]
    public function showSecteur(string $secteur, Request $request, PaginatorInterface $paginator) {

        $etablissements = $this->getDoctrine()
            ->getRepository(Etablissement::class)
            ->findBySecteur($secteur);

        if (!$etablissements) {
            throw $this->createNotFoundException(
                "Aucun établissement avec ce secteur ".$secteur
            );
        }

        $articles = $paginator->paginate(
            $etablissements,
            $request->query->getInt('page', 1),
            50
        );

        return $this->render('etablissement/etablissement.html.twig', array(
            'articles' => $articles,'vu'=>' Secteur : '.$secteur));
    }


    #[Route('/new', name: 'app_etablissement_new', methods: ['GET', 'POST'])]
    public function new(Request $request, EtablissementRepository $etablissementRepository): Response
    {
        $etablissement = new Etablissement();
        $form = $this->createForm(EtablissementType::class, $etablissement);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $etablissementRepository->add($etablissement);
            return $this->redirectToRoute('app_etablissement_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->renderForm('etablissement/new.html.twig', [
            'etablissement' => $etablissement,
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_etablissement_show', methods: ['GET'])]
    public function show(Etablissement $etablissement): Response
    {
        return $this->render('etablissement/show.html.twig', [
            'etablissement' => $etablissement,
        ]);
    }

    #[Route('/{id}/edit', name: 'app_etablissement_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, Etablissement $etablissement, EtablissementRepository $etablissementRepository): Response
    {
        $form = $this->createForm(EtablissementType::class, $etablissement);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $etablissementRepository->add($etablissement);
            return $this->redirectToRoute('app_etablissement_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->renderForm('etablissement/edit.html.twig', [
            'etablissement' => $etablissement,
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_etablissement_delete', methods: ['POST'])]
    public function delete(Request $request, Etablissement $etablissement, EtablissementRepository $etablissementRepository): Response
    {
        if ($this->isCsrfTokenValid('delete'.$etablissement->getId(), $request->request->get('_token'))) {
            $etablissementRepository->remove($etablissement);
        }

        return $this->redirectToRoute('app_etablissement_index', [], Response::HTTP_SEE_OTHER);
    }
}
